pygeodesy.heights.HeightIDWdistanceTo

Package pygeodesy :: Module heights :: Class HeightIDWdistanceTo |
[frames] | no frames]

# Class HeightIDWdistanceTo

      object --+
               |
    named._Named --+
                   |
        _HeightNamed --+
                       |
              _HeightIDW --+
                           |
                          HeightIDWdistanceTo

Height interpolator using Inverse Distance Weighting (IDW) and the points' `LatLon.distanceTo` method.

Instance Methods
__init__(self, knots, beta=2, **name__distanceTo_kwds) New HeightIDWdistanceTo interpolator. |
__call__(self, *llis, **wrap) Interpolate the height for one or several locations. |
height(self, lats, lons, **wrap) Interpolate the height for one or several lat-/longitudes. |
Inherited from `_HeightNamed`: `height_` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__repr__`, `__rmatmul__`, `__str__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toRepr`, `toStr`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `_HeightIDW`: `adjust`, `beta`, `datum`, `hypot`, `knots`, `kwds`, `limit`, `radius`, `scaled`, `wrap` Inherited from `_HeightNamed`: `kmin` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, knots, beta=2, **name__distanceTo_kwds) (Constructor) |
New HeightIDWdistanceTo interpolator. Arguments: `name__distanceTo_kwds` - Optional `name=NN` for this height interpolator (`str`) and keyword arguments for `knots`' method `LatLon.distanceTo`. Raises: `HeightError` - Insufficient number of `knots` or an invalid `knot` or `beta`. Overrides: object.__init__ See Also: Here for further details. Note: All `points` must be instances of the same ellipsoidal or spherical `LatLon` class, not checked.

### __call__ (self, *llis, **wrap) (Call operator) |
Interpolate the height for one or several locations. Arguments: `llis` - One or more locations (`LatLon`s), all positional. `wrap` - If `True`, wrap or normalize all `llis` locations (`bool`). Returns: A single interpolated height (`float`) or a list or tuple of interpolated heights (`float`s). Raises: `HeightError` - Insufficient number of `llis`, an invalid `lli` or pygeodesy.fidw issue. Overrides: _HeightNamed.__call__

### height (self, lats, lons, **wrap) |
Interpolate the height for one or several lat-/longitudes. Arguments: `lats` - Latitude or latitudes (each `degrees`). `lons` - Longitude or longitudes (each `degrees`). `wrap` - Keyword argument `wrap=False` (`bool`). Use `wrap=True` to wrap or normalize all `lats` and `lons`. Returns: A single interpolated height (`float`) or a list of interpolated heights (each `float`). Raises: `HeightError` - Insufficient or unequal number of `lats` and `lons` or a pygeodesy.fidw issue. Overrides: _HeightNamed.height